@@ -33,7 +33,7 @@ try:
     hresult, hcontext = SCardEstablishContext(SCARD_SCOPE_USER)
     if hresult != SCARD_S_SUCCESS:
         raise error(
-            'Failed to establish context: ' + \
+            'Failed to establish context: ' +
             SCardGetErrorMessage(hresult))
     print('Context established!')
 
@@ -41,14 +41,14 @@ try:
         hresult, readers = SCardListReaders(hcontext, [])
         if hresult != SCARD_S_SUCCESS:
             raise error(
-                'Failed to list readers: ' + \
+                'Failed to list readers: ' +
                 SCardGetErrorMessage(hresult))
         print('PCSC Readers:', readers)
 
         hresult, readerGroups = SCardListReaderGroups(hcontext)
         if hresult != SCARD_S_SUCCESS:
             raise error(
-                'Unable to list reader groups: ' + \
+                'Unable to list reader groups: ' +
                 SCardGetErrorMessage(hresult))
         print('PCSC Reader groups:', readerGroups)
 
@@ -56,7 +56,7 @@ try:
         hresult = SCardReleaseContext(hcontext)
         if hresult != SCARD_S_SUCCESS:
             raise error(
-                'Failed to release context: ' + \
+                'Failed to release context: ' +
                 SCardGetErrorMessage(hresult))
         print('Released context.')
 
