@@ -22,6 +22,7 @@ along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
+from __future__ import print_function
 from smartcard.sw.ErrorChecker import ErrorChecker
 import smartcard.sw.SWExceptions
 
@@ -47,21 +48,21 @@ class ISO7816_4_SW1ErrorChecker(ErrorChecker):
     """ISO7816-4 error checker based on status word sw1 only.
 
     This error checker raises the following exceptions:
-    - sw1 sw2
-    - 62  any   WarningProcessingException
-    - 63  any   WarningProcessingException
-    - 64  any   ExecutionErrorException
-    - 65  any   ExecutionErrorException
-    - 66  any   SecurityRelatedException
-    - 67  any   CheckingErrorException
-    - 68  any   CheckingErrorException
-    - 69  any   CheckingErrorException
-    - 6a  any   CheckingErrorException
-    - 6b  any   CheckingErrorException
-    - 6c  any   CheckingErrorException
-    - 6d  any   CheckingErrorException
-    - 6e  any   CheckingErrorException
-    - 6f  any   CheckingErrorException
+      - sw1 sw2
+      - 62  any   WarningProcessingException
+      - 63  any   WarningProcessingException
+      - 64  any   ExecutionErrorException
+      - 65  any   ExecutionErrorException
+      - 66  any   SecurityRelatedException
+      - 67  any   CheckingErrorException
+      - 68  any   CheckingErrorException
+      - 69  any   CheckingErrorException
+      - 6a  any   CheckingErrorException
+      - 6b  any   CheckingErrorException
+      - 6c  any   CheckingErrorException
+      - 6d  any   CheckingErrorException
+      - 6e  any   CheckingErrorException
+      - 6f  any   CheckingErrorException
     """
 
     def __call__(self, data, sw1, sw2):
@@ -81,5 +82,5 @@ if __name__ == '__main__':
     ecs([], 0x90, 0x00)
     try:
         ecs([], 0x66, 0x80)
-    except smartcard.sw.SWExceptions.SecurityRelatedException, e:
-        print e, "%x %x" % (e.sw1, e.sw2)
+    except smartcard.sw.SWExceptions.SecurityRelatedException as e:
+        print(str(e) + " %x %x" % (e.sw1, e.sw2))
