@@ -27,6 +27,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
 
+from __future__ import print_function
 import unittest
 
 # import local_config for reader/card configuration
@@ -38,8 +39,8 @@ sys.path += ['..']
 try:
     from local_config import expectedATRs, expectedReaders
     from local_config import expectedReaderGroups, expectedATRinReader
-except:
-    print 'execute test suite first to generate the local_config.py file'
+except ImportError:
+    print('execute test suite first to generate the local_config.py file')
     sys.exit()
 
 
@@ -54,11 +55,8 @@ if 'winscard' == resourceManager:
 
         def setUp(self):
             groups = PCSCReaderGroups().instance
-            try:
-                groups.remove('Pinpad$Readers')
-                groups.remove('Biometric$Readers')
-            except:
-                pass
+            groups.remove('Pinpad$Readers')
+            groups.remove('Biometric$Readers')
 
         def testcase_add(self):
             """Test for groups=groups+newgroups"""
@@ -66,7 +64,7 @@ if 'winscard' == resourceManager:
             groups = PCSCReaderGroups().instance
             newgroup = 'Pinpad$Readers'
             groups = groups + newgroup
-            self.assertEquals(groups, groupssnapshot + [newgroup])
+            self.assertEqual(groups, groupssnapshot + [newgroup])
             groups.remove(newgroup)
 
         def testcase_addlist(self):
@@ -75,7 +73,7 @@ if 'winscard' == resourceManager:
             groups = PCSCReaderGroups().instance
             newgroups = ['Pinpad$Readers', 'Biometric$Readers']
             groups = groups + newgroups
-            self.assertEquals(groups, groupssnapshot + newgroups)
+            self.assertEqual(groups, groupssnapshot + newgroups)
             for group in newgroups:
                 groups.remove(group)
 
@@ -85,7 +83,7 @@ if 'winscard' == resourceManager:
             groups = PCSCReaderGroups().instance
             newgroup = 'Pinpad$Readers'
             groups += newgroup
-            self.assertEquals(groups, groupssnapshot + [newgroup])
+            self.assertEqual(groups, groupssnapshot + [newgroup])
             groups.remove(newgroup)
 
         def testcase_iaddlist(self):
@@ -94,7 +92,7 @@ if 'winscard' == resourceManager:
             groups = PCSCReaderGroups().instance
             newgroups = ['Pinpad$Readers', 'Biometric$Readers']
             groups += newgroups
-            self.assertEquals(groups, groupssnapshot + newgroups)
+            self.assertEqual(groups, groupssnapshot + newgroups)
             for group in newgroups:
                 groups.remove(group)
 
@@ -104,7 +102,7 @@ if 'winscard' == resourceManager:
             groups = PCSCReaderGroups().instance
             newgroup = 'Pinpad$Readers'
             groups.append(newgroup)
-            self.assertEquals(groups, groupssnapshot + [newgroup])
+            self.assertEqual(groups, groupssnapshot + [newgroup])
             groups.remove(newgroup)
 
         def testcase_insert(self):
@@ -113,7 +111,7 @@ if 'winscard' == resourceManager:
             groups = PCSCReaderGroups().instance
             newgroup = 'Pinpad$Readers'
             groups.insert(0, newgroup)
-            self.assertEquals(groups, [newgroup] + groupssnapshot)
+            self.assertEqual(groups, [newgroup] + groupssnapshot)
             groups.remove(newgroup)
 
         def testcase_removereadergroup_pop(self):
@@ -122,9 +120,9 @@ if 'winscard' == resourceManager:
             groups = PCSCReaderGroups().instance
             newgroup = 'Pinpad$Readers'
             groups.insert(0, newgroup)
-            self.assertEquals(groups, [newgroup] + groupssnapshot)
+            self.assertEqual(groups, [newgroup] + groupssnapshot)
             groups.pop(0)
-            self.assertEquals(groups, groupssnapshot)
+            self.assertEqual(groups, groupssnapshot)
 
         def testcase_addreadertogroup(self):
             """Test for adding readers to group"""
@@ -133,12 +131,12 @@ if 'winscard' == resourceManager:
             groups.insert(0, newgroup)
             for r in PCSCReader.readers('SCard$DefaultReaders'):
                 r.addtoreadergroup(newgroup)
-            self.assertEquals(
+            self.assertEqual(
                 PCSCReader.readers(
                     'SCard$DefaultReaders'),
                 PCSCReader.readers(newgroup))
             groups.pop(0)
-            self.assertEquals([], PCSCReader.readers(newgroup))
+            self.assertEqual([], PCSCReader.readers(newgroup))
 
         def testcase_removereaderfromgroup(self):
             """Test for removing readers from group"""
@@ -147,15 +145,15 @@ if 'winscard' == resourceManager:
             groups.insert(0, newgroup)
             for r in PCSCReader.readers('SCard$DefaultReaders'):
                 r.addtoreadergroup(newgroup)
-            self.assertEquals(
+            self.assertEqual(
                 PCSCReader.readers(
                     'SCard$DefaultReaders'),
                 PCSCReader.readers(newgroup))
             for r in PCSCReader.readers('SCard$DefaultReaders'):
                 r.removefromreadergroup(newgroup)
-            self.assertEquals([], PCSCReader.readers(newgroup))
+            self.assertEqual([], PCSCReader.readers(newgroup))
             groups.pop(0)
-            self.assertEquals([], PCSCReader.readers(newgroup))
+            self.assertEqual([], PCSCReader.readers(newgroup))
 
     def suite():
         suite1 = unittest.makeSuite(testcase_readergroups)
